<?php
/*
Plugin Name: WP-Tabbity
Description: Creates tabbed display of content based on shortcode entered by user.
Version: 0.4
Author: Tom Belknap
Author URI: http://holisticnetworking.net
Plugin URI: http://holisticnetworking.net/plugins/2010/02/27/wp-tabbity/
*/

include_once('wp-tabbity.class.php');
$tabbity = new wpTabbity;

/*
// wpTabbity_shortcode:		Does the work of parsing and creating tabs on post load.
// @var str $atts:			The included attributes from the shortcode.
// @var str $content:		The post content contained in the shortcode.
// @return str $output:		A <div> created to hold the content of this tab group.
*/
function wpTabbity_shortcode($atts, $content) {
	global $tabbity;
	$defaultid		= str_split(strip_tags($content), 10);
	extract(shortcode_atts(array(
		'groupid'	=> $tabbity->groupid,
		'title'		=> trim($defaultid[0]),
		'id' 		=> sanitize_title_with_dashes(trim($defaultid[0])),
		'class'		=> $tabbity->class,
		'order'		=> $tabbity->order
	), $atts));
	$tabbity->addTab($groupid, $title, $id, $class, $order, $content);
	// return 'No, you are not crazy.';
}

/*
//
*/
function wpTabbityGroup_shortcode($atts) {
	global $tabbity;
	extract(shortcode_atts(array(
		'groupcls'		=> $tabbity->groupcls,
		'groupid'		=> $tabbity->groupid,
		'grouptitle'	=> $tabbity->grouptitle,
	), $atts));
	$output = $tabbity->addGroup($groupid, $groupcls, $grouptitle);
	return $output;
}



/*
// wpTabbity_init:	Enqueues the correct scripts to launch the jQuery tabs
*/
function wpTabbity_init() {
	wp_enqueue_script('tabbity', WP_PLUGIN_URL . '/wp-tabbity/wp-tabbity-script.js', array('jquery', 'jquery-ui-core', 'jquery-ui-tabs'), '1.0');
}

/*
// wpTabbity_printStyles:	Adds the CSS styles to the page.
*/
function wpTabbity_printStyles() {
	global $tabbity;
	$bigTabbityStyle = WP_PLUGIN_URL . $tabbity->css;
	$bigTabbityFile = WP_PLUGIN_DIR . $tabbity->css;
	if (file_exists($bigTabbityFile)) {
		wp_register_style('wpTabbity', $bigTabbityStyle);
		wp_enqueue_style('wpTabbity');
	}
}



/*
// wpTabbity_admin:		Administration panel
*/
function wpTabbity_add_menu() {
	global $tabbity;
	add_options_page('WP-Tabbity', 'WP-Tabbity', 8, basename(__FILE__),'wpTabbity_control');
	add_action('admin_init', array(&$tabbity, 'registerSettings'));
}

/*
// wpTabbity_control
*/
function wpTabbity_control() {
	global $tabbity;
	$themes	= $tabbity->getThemes();
	?>
<div class="wrap">
	<h2>WP-Tabbity</h2>
    <form method="post" action="options.php">
        <?php settings_fields( 'wp-tabbity' ); ?>
        <?php do_settings_sections('wp-tabbity'); ?>
        <input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
    </form>
</div>
    <?php
}


// Finally, add our methods to WordPress:
if ( is_admin() ){ // admin actions
	add_action('admin_menu', 'wpTabbity_add_menu');
} else {
	add_shortcode('wp-tabbity', 'wpTabbity_shortcode');
	add_shortcode('wp-tabbitygroup', 'wpTabbityGroup_shortcode');
	add_action('init', 'wpTabbity_init');
	add_action('wp_print_styles', 'wpTabbity_printStyles');
}


?>